@@ -17,4 +17,7 @@ else
                 su - $user -c "xscreensaver-command -unthrottle"
         fi
         chvt `cat $LIDSTATE`
+        su - $user -c "xscreensaver-command -deactivate"
 fi
+
+[ -x /etc/acpi/local/lid.sh.post ] && /etc/acpi/local/lid.sh.post
