@@ -2,8 +2,11 @@
 
 . /usr/share/acpi-support/power-funcs
 
+getState;
 getXuser;
 
+checkStateChanged;
+
 sleep 5;
 grep -q off-line /proc/acpi/ac_adapter/*/state
 if [ $? = 0 ]
@@ -12,11 +15,11 @@ if [ $? = 0 ]
         $LAPTOP_MODE start
         $HDPARM -S 12 /dev/hda
         $HDPARM -B 1 /dev/hda
-        su $user -c "xscreensaver-command -throttle"
+        su $user -c "xscreensaver-command -throttle" &
 else
         xset dpms 0 0 600
         $LAPTOP_MODE stop
         $HDPARM -S 0 /dev/hda
         $HDPARM -B 255 /dev/hda
-        su $user -c "xscreensaver-command -unthrottle"
+        su $user -c "xscreensaver-command -unthrottle" &
 fi
